"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const bytes = require("bytes-iec");
function cpuFraction(str) {
    return parseInt(str.replace(/%$/, ''), 10);
}
exports.cpuFraction = cpuFraction;
function cpuShare(str) {
    if (/m$/.test(str)) {
        return parseInt(str.replace(/m$/, ''), 10);
    }
    else {
        return parseInt(str, 10) * 1000;
    }
}
exports.cpuShare = cpuShare;
const byte = 1;
const kilobytes = 1024 * byte;
const megabytes = 1024 * kilobytes;
const gigabytes = 1024 * megabytes;
const terabytes = 1024 * gigabytes;
const petabytes = 1024 * terabytes;
const exabytes = 1024 * petabytes;
function memShare(str) {
    let end = 2;
    let unit = byte;
    if (/Ei$/.test(str)) {
        unit = exabytes;
    }
    else if (/Pi$/.test(str)) {
        unit = petabytes;
    }
    else if (/Ti$/.test(str)) {
        unit = terabytes;
    }
    else if (/Gi$/.test(str)) {
        unit = gigabytes;
    }
    else if (/Mi$/.test(str)) {
        unit = megabytes;
    }
    else if (/Ki$/.test(str)) {
        unit = kilobytes;
    }
    else {
        end = 1;
    }
    return parseInt(str.slice(0, str.length - end), 10) * unit;
}
exports.memShare = memShare;
function formatAsBytes(mem) {
    if (mem < kilobytes) {
        return mem.toString();
    }
    else if (mem < 10 * megabytes) {
        return (mem / kilobytes).toFixed(0) + 'Ki';
    }
    else if (mem < 10 * gigabytes) {
        return (mem / megabytes).toFixed(0) + 'Mi';
    }
    else if (mem < 10 * terabytes) {
        return (mem / gigabytes).toFixed(0) + 'Gi';
    }
    else if (mem < 10 * petabytes) {
        return (mem / terabytes).toFixed(0) + 'Ti';
    }
    else {
        return (mem / petabytes).toFixed(0) + 'Pi';
    }
}
exports.formatAsBytes = formatAsBytes;
function formatAsCpu(cpu) {
    return cpu > 10000 ? (cpu / 1000).toFixed(0) : `${cpu}m`;
}
exports.formatAsCpu = formatAsCpu;
function parseAsTime(str) {
    return cpuShare(str).toString();
}
exports.parseAsTime = parseAsTime;
function fromSize(str) {
    return bytes(str
        .replace(/m/g, 'MB')
        .replace(/Ki/g, 'KiB')
        .replace(/Mi/g, 'MiB')
        .replace(/Gi/g, 'GiB')
        .replace(/Ti/g, 'TiB')
        .replace(/Pi/g, 'PiB')
        .replace(/Ei/g, 'EiB'));
}
exports.fromSize = fromSize;
function sumTime(table, attrIdx, backupAttrIdx = attrIdx) {
    return table.body
        .map(_ => cpuShare(_.attributes[attrIdx].value === '0' ? _.attributes[backupAttrIdx].value : _.attributes[attrIdx].value))
        .reduce((sum, _) => sum + _, 0);
}
exports.sumTime = sumTime;
function sumSize(table, attrIdx, backupAttrIdx = attrIdx) {
    return table.body
        .map(_ => fromSize(_.attributes[attrIdx].value === '0Ki' ? _.attributes[backupAttrIdx].value : _.attributes[attrIdx].value))
        .reduce((sum, _) => sum + _, 0);
}
exports.sumSize = sumSize;
function parseAsSize(str) {
    return bytes(fromSize(str), {});
}
exports.parseAsSize = parseAsSize;
exports.default = parseAsSize;
//# sourceMappingURL=parse.js.map