var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { i18n, isTable } from '@kui-shell/core';
import { getNamespace, getNamespaceForArgv, getLabelForArgv, isForAllNamespaces } from '@kui-shell/plugin-kubeui';
import { strip, getSystemOverhead } from './get-node-data';
import { formatAsBytes, formatAsCpu, cpuShare, memShare } from '../lib/parse';
const strings = i18n('plugin-view-utilization', 'table');
function getPodsInNode(args, forNode) {
    return __awaiter(this, void 0, void 0, function* () {
        const { content } = yield args.REPL.rexec(`kubectl get pods -o json ${getNamespaceForArgv(args)} ${getLabelForArgv(args)}`);
        const empty = {};
        if (content && content.items) {
            return content.items
                .filter(_ => _.spec.nodeName === forNode)
                .map(_ => _.metadata.name)
                .reduce((M, fqn) => {
                M[fqn] = true;
                return M;
            }, empty);
        }
        else {
            return empty;
        }
    });
}
function withAllNamespaces(args) {
    const args2 = Object.assign({}, args);
    args2.command = args2.command + ' -A';
    args2.argv = args2.argv.slice(0).concat(['-A']);
    return args2;
}
const lighterText = ['processing-text', 'semi-bold'];
function addRow(forThisNS, key, cpu, mem, css, formatAs = 'share') {
    const row = JSON.parse(JSON.stringify(forThisNS.body[0]));
    row.onclick = false;
    row.rowKey = key;
    row.name = strings(key);
    row.attributes[0].value = formatAs === 'share' ? formatAsCpu(cpu) : (100 * cpu).toFixed(0) + '%';
    row.attributes[1].value = formatAs === 'share' ? formatAsBytes(mem) : (100 * mem).toFixed(0) + '%';
    if (css) {
        row.css = css;
        row.attributes[0].css = css.join(' ');
        row.attributes[1].css = css.join(' ');
    }
    forThisNS.body.push(row);
}
function addAllNSRow(args, forThisNS, forAllNS) {
    if (forThisNS.body && forThisNS.body.length > 0) {
        const cpuTotal = forThisNS.body.reduce((total, row) => total + cpuShare(row.attributes[0].value), 0);
        const memTotal = forThisNS.body.reduce((total, row) => total + memShare(row.attributes[1].value), 0);
        addRow(forThisNS, 'Total', cpuTotal, memTotal);
        if (forAllNS.body && forAllNS.body.length > 0) {
            const thisNS = getNamespace(args) || 'default';
            const otherNS = forAllNS.body.filter(_ => _.name !== thisNS);
            const cpuTotal = otherNS.reduce((total, row) => total + cpuShare(row.attributes[1].value), 0);
            const memTotal = otherNS.reduce((total, row) => total + memShare(row.attributes[2].value), 0);
            addRow(forThisNS, 'Other Namespaces', cpuTotal, memTotal, lighterText);
        }
    }
    return forThisNS;
}
function getPodDataForAllNodes(args, top) {
    return __awaiter(this, void 0, void 0, function* () {
        if (isForAllNamespaces(args) || args.parsedOptions.containers) {
            return top(args);
        }
        else {
            const [forThisNS, forAllNS] = yield Promise.all([top(args), top(withAllNamespaces(args))]);
            return addAllNSRow(args, forThisNS, forAllNS);
        }
    });
}
function getPodDataForOneNode(args, top) {
    return __awaiter(this, void 0, void 0, function* () {
        const forNode = args.parsedOptions.node;
        strip(args, '--node', 1);
        if (isForAllNamespaces(args) || args.parsedOptions.containers) {
            const [podTable, pods] = yield Promise.all([top(args), getPodsInNode(args, forNode)]);
            if (podTable.body) {
                podTable.body = podTable.body.filter(row => pods[row.name]);
            }
            return podTable;
        }
        else {
            const [podTable, pods, podTableInAllNS] = yield Promise.all([
                top(args),
                getPodsInNode(args, forNode),
                top(withAllNamespaces(args))
            ]);
            if (podTable.body) {
                podTable.body = podTable.body.filter(row => pods[row.name]);
            }
            if (podTableInAllNS.body) {
                podTableInAllNS.body = podTableInAllNS.body.filter(row => pods[row.attributes[0].value]);
            }
            return addAllNSRow(args, podTable, podTableInAllNS);
        }
    });
}
export function topPod(args, top) {
    return __awaiter(this, void 0, void 0, function* () {
        const overheads = getSystemOverhead(args, args.parsedOptions.node);
        const table = !args.parsedOptions.node
            ? yield getPodDataForAllNodes(args, top)
            : yield getPodDataForOneNode(args, top);
        if (!isTable(table)) {
            return table;
        }
        else if (table.body.length === 0) {
            throw new Error(strings('No pods found'));
        }
        table.body.forEach(row => {
            if (row.onclick) {
                row.onclick = `kubectl top container ${args.REPL.encodeComponent(row.name)} ${getNamespaceForArgv(args)} ${getLabelForArgv(args)}`;
                row.onclickSilence = false;
            }
        });
        const { cpuOverhead, memOverhead } = yield overheads;
        addRow(table, 'System Overheads', cpuOverhead, memOverhead, lighterText);
        const totalRow = table.body.find(_ => _.rowKey === 'Total');
        const otherNSRow = table.body.find(_ => _.rowKey === 'Other Namespaces');
        if (totalRow && otherNSRow) {
            const totalCPU = cpuShare(totalRow.attributes[0].value) + cpuShare(otherNSRow.attributes[0].value) + cpuOverhead;
            const totalMem = memShare(totalRow.attributes[1].value) + memShare(otherNSRow.attributes[1].value) + memOverhead;
            addRow(table, strings('Overall Total'), totalCPU, totalMem, lighterText);
        }
        return table;
    });
}
export function topContainer(args) {
    return __awaiter(this, void 0, void 0, function* () {
        const cmd = args.command.replace('top container', 'top pod').replace(/(-A|--all-namespaces)/, '') + ' --containers';
        const allContainers = yield args.REPL.qexec(cmd);
        const pod = args.argvNoOptions[args.argvNoOptions.indexOf('container') + 1];
        if (allContainers.body) {
            allContainers.body = allContainers.body.filter(_ => _.name === pod);
            allContainers.body.forEach(row => {
                row.onclick = `kubectl get pod ${args.REPL.encodeComponent(row.name)} -o yaml`;
            });
        }
        return allContainers;
    });
}
//# sourceMappingURL=get-pod-data.js.map