var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import Debug from 'debug';
import { i18n } from '@kui-shell/core';
import { bar, barContainer } from '../bar';
const debug = Debug('plugin-view-utilization/widgets/cluster-utilization');
const strings = i18n('plugin-view-utilization', 'widgets');
const icon = '';
function bars() {
    const container = barContainer();
    const cpuBar = bar(container, "var(--color-latency-0)");
    const memBar = bar(container, "var(--color-latency-1)");
    return { container, cpuBar, memBar };
}
function listener(tab, controller, fragment) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const { content: info } = yield tab.REPL.rexec('kubectl top node-summary');
            const cpu = 100 * info.cpuFrac + '%';
            const mem = 100 * info.memFrac + '%';
            fragment.cpuBar.style.width = cpu;
            fragment.cpuBar.title = strings('Cluster CPU', cpu);
            fragment.memBar.style.width = mem;
            fragment.memBar.title = strings('Cluster Memory', mem);
            controller.showAs('normal');
        }
        catch (err) {
            debug(err);
            controller.showAs('hidden');
        }
    });
}
export default function () {
    const { container: text, cpuBar, memBar } = bars();
    const fragment = {
        id: 'kui--plugin-view-utilization--cluster-utilization',
        icon,
        text,
        onclick: {
            text: 'kubectl top node'
        },
        cpuBar,
        memBar
    };
    return {
        fragment,
        listener
    };
}
//# sourceMappingURL=cluster-utilization.js.map